pypirc Management Client

This is hopefully a temporary fork as the official project looks dead.


Installation
============

Install from 'the' pypi::

    pip install pypirc


Usage Example
=============

Display current pypi configuration::

    pypirc

Add a pypi server::

    pypirc -s mypypi -u foo -p bar -r http://mypypi.example.com/


Source
======

Official: https://github.com/ampledata/pypirc

Chappers: https://github.com/chappers/pypirc

Author
======
Greg Albrecht gba@splunk.com

http://ampledata.org/

Unofficial
==========

Chapman Siu chapm0n.siu@gmail.com


Copyright
=========
Copyright 2012 Splunk, Inc.


License
=======
Apache License 2.0
